@@ -3,10 +3,11 @@ package Dist::Zilla::Plugin::InsertExample;
 use strict;
 use warnings;
 use Moose;
+use Path::Class qw( dir );
 use List::Util qw( first );
 
 # ABSTRACT: Insert example into your POD from a file
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -46,7 +47,7 @@ sub _slurp_example
     my $content = $file->content;
     open $fh, '<', \$content;
   }
-  elsif($file = $self->zilla->root->file($filename))
+  elsif($file = dir($self->zilla->root)->file($filename))
   {
     $self->log_fatal("no such example file $filename") unless -r $file;
     $fh = $file->openr;  
@@ -83,7 +84,7 @@ Dist::Zilla::Plugin::InsertExample - Insert example into your POD from a file
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
